;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "apheleia" "20251111.1140"
  "Reformat buffer stably."
  '((emacs "27"))
  :url "https://github.com/radian-software/apheleia"
  :commit "e7892adc8a23612b219513ea56f62cdb825afe8f"
  :revdesc "e7892adc8a23"
  :keywords '("tools")
  :authors '(("Radian LLC" . "contact+apheleia@radian.codes"))
  :maintainers '(("Radian LLC" . "contact+apheleia@radian.codes")))
